@@ -1,11 +1,13 @@
 from colorama import Fore, Style
 import sys
+import logging
 from sylo.models import Durations
 from pyfiglet import figlet_format
+logger = logging.getLogger(__name__)
 
 
 def print_message(message: str, timer_val: int = None):
-
+    logger.debug(f'Printing message: {message} with a timer_val of {timer_val}')
     if message == "work_start":
         print(f"{Fore.RED}WORK{Style.RESET_ALL} for {Fore.YELLOW}{timer_val}{Style.RESET_ALL} minutes")
     elif message == "rest_start":
@@ -25,6 +27,7 @@ Q       --    Quit SYLO
 
 
 def print_update(durations: Durations, mode: str, show_options: bool = False):
+    logger.debug(f'Printing update: {mode} with show_options {show_options}')
     if mode == 'rest':
         upcoming_timer_color = durations.rest.bar_color
     else:
