@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 import sys
+import logging
 import time
 import simpleaudio
 from beepy import beep
@@ -21,6 +22,7 @@ from sylo.utils import (
     flip_mode,
 )
 
+logger = logging.getLogger(__name__)
 
 is_double = False
 timer_mode = 'work'
@@ -57,9 +59,13 @@ class Timer:
             time.sleep(1)
             self.secs -= self.increments
             timer_iterator.update(self.increments)
+            if self.secs % 60 == 0:
+                logger.debug(f'{self.mode} Timer loop: secs remaining: {self.secs}')
+        logger.info(f'{self.mode} timer loop finished')
         timer_iterator.close()
 
     def start_countdown(self):
+        logger.info(f'{self.mode} timer started')
         self.start_timer()
 
 
@@ -71,18 +77,25 @@ class Sound:
         self.initialised_file = None
 
     def initialise(self):
+        logger.info(f'Initialising audio: {self.sound_file}')
         try:
             self.initialised_file = simpleaudio.WaveObject.from_wave_file(
                 self.sound_file
             )
+            logger.info(f'Custom audio successfully initialised: {self.sound_file}')
         except FileNotFoundError:
+            logger.info(f'Custom audio not found: {self.sound_file}')
             self.beep_needed = True
 
     def play_sound(self):
         if self.beep_needed is False:
             play_obj = self.initialised_file.play()
+            logger.info('Played audio file')
             play_obj.wait_done()
+            logger.info('Waiting audio file')
+
         else:
+            logger.info('Playing beep')
             beep("ready")
 
 
@@ -93,12 +106,18 @@ def sylo(
         show_options: bool,
         double: bool = is_double,
 ):
+    logger.info(f'Running sylo in {mode} mode')
+    logger.info(f'Running sylo with show_options set to {show_options}')
+    logger.info(f'Running sylo with double set to {double}')
+    logger.info(f'Running sylo with total mins set to {durations_model.total_mins}')
+
     clear_screen()
 
     if double is True:
         increments = 30
     else:
         increments = COUNTDOWN_INCREMENTS
+    logger.debug(f'Running in {increments} second increments')
 
     timer = Timer(mode, durations_model, increments)
     print_header_small(double=is_double, font='bubble')
@@ -106,9 +125,11 @@ def sylo(
     print_update(timer.durations, mode, show_options)
 
     response = input("> ")
+    logger.info(f'User response: {response}')
 
     while response.lower() not in WELCOME_CHOICES:
         show_options = True
+        logger.info(f'Rejected user response of {response}')
         sylo(
             durations_model=durations_model,
             sound_obj=sound_obj,
@@ -117,9 +138,11 @@ def sylo(
             double=double,
         )
     while response.lower() == "q":
+        logger.info('Quit requested')
         clear_screen()
         sys.exit()
     while response.lower() == "s":
+        logger.info('Switch requested')
         new_mode = flip_mode(mode)
         sylo(
             durations_model=durations_model,
@@ -129,6 +152,7 @@ def sylo(
             double=double,
         )
     while response.lower() == "h":
+        logger.info('Help requested')
         show_options = True
         sylo(durations_model=durations_model,
              sound_obj=sound_obj,
@@ -138,19 +162,20 @@ def sylo(
              )
     clear_screen()
     while response == "":
+        logger.info('User pressed ENTER')
         if mode == 'rest':
             timer.start_countdown()
             sound_obj.play_sound()
-            mode = 'work'
+            next_mode = flip_mode(mode)
         else:
             timer.start_countdown()
             sound_obj.play_sound()
             durations_model.total_mins += durations_model.work.mins
-            mode = 'rest'
+            next_mode = flip_mode(mode)
         sylo(
             durations_model=durations_model,
             sound_obj=sound_obj,
-            mode=mode,
+            mode=next_mode,
             show_options=False,
             double=double,
         )
@@ -168,14 +193,25 @@ def run(args):
     if args.rest_time:
         durations_data.rest.mins = args.rest_time
         durations_data.rest.secs = mins_to_secs(args.rest_time)
+
+    logger.info('Durations model set')
+    logger.info(f'Work time: {durations_data.work.mins}')
+    logger.info(f'Work time: {durations_data.work.secs}')
+    logger.info(f'Work time: {durations_data.rest.mins}')
+    logger.info(f'Work time: {durations_data.rest.secs}')
+
     if args.double_speed is True:
         is_double = True
+    logger.info(f'Double speed set to {is_double}')
+
     if args.audio_file:
         sound = Sound(audio_path=args.audio_file)
+        logger.debug(f'Custom audio file path specified {sound}')
     else:
         sound = Sound()
-    print(args.audio_file)
+        logger.debug('Using default audio')
     sound.initialise()
+    logger.debug('Sound initialised')
 
     sylo(
         durations_model=durations_data,
